.github
.grunt
.phpstorm.meta.php
.upgradenotes
admin
lib
.eslintrc
.gherkin-lintrc
.gitattributes
.jshintignore
.jshintrc
.nvmrc
.shifter.json
.stylelintrc
composer.json
composer.lock
config-dist.php
CONTRIBUTING.md
COPYING.txt
githash.php
Gruntfile.js
index.php
INSTALL.txt
npm-shrinkwrap.json
package.json
phpcs.xml.dist
phpunit.xml.dist
README.md
TRADEMARK.txt
UPGRADING.md
config.php